==> nimbus_scrapy-3.4.0-py2.py3-none-any.whl: nimbus_scrapy/callback/db.py <==
# -*- coding: utf-8 -*-
from __future__ import absolute_import, print_function, division, unicode_literals
import traceback
import logging
from scrapy.exceptions import DropItem
from .item import SpiderItemCallback
from ..models import BaseModel


class SpiderDBItemCallback(SpiderItemCallback):
    _db_session = None
    model_mapping = {
    }

    def init_db_session(self, spider=None):
        raise NotImplementedError

    def get_model_kwargs(self, item, spider=None):
        return {}

    def get_model_cls(self, item):
        item_type = type(item)
        return self.model_mapping.get(item_type, None)

    def process_item(self, item, spider=None, *args, **kwargs):
        db = self.get_db_session(spider)
        if not db:
            raise DropItem("db session is none, item -> {}".format(item))
        try:
            model_cls = self.get_model_cls(item)
            model_kwargs = self.get_model_kwargs(item, spider)
            if model_cls and issubclass(model_cls, BaseModel):
                model = model_cls.save(item, **model_kwargs)
                db.add(model)
                db.commit()
        except Exception as e:
            db.rollback()
            error = traceback.format_exc()
            spider.log(error, level=logging.ERROR)
            raise DropItem("db commit error, item -> {}".format(item))
        return item

    def get_db_session(self, spider=None):
        if self._db_session:
            return self._db_session
        self._db_session = self.init_db_session(spider=spider)
        return self._db_session

==> nimbus_scrapy-3.4.1-py2.py3-none-any.whl: nimbus_scrapy/callback/db.py <==
# -*- coding: utf-8 -*-
from __future__ import absolute_import, print_function, division, unicode_literals
import traceback
import logging
from scrapy.exceptions import DropItem
from .item import SpiderItemCallback
from ..models import BaseModel


class SpiderDBItemCallback(SpiderItemCallback):
    _db_session = None
    model_mapping = {
    }

    def init_db_session(self, item=None, spider=None):
        raise NotImplementedError

    def get_model_kwargs(self, item=None, spider=None):
        raise NotImplementedError

    def get_model_cls(self, item):
        item_type = type(item)
        return self.model_mapping.get(item_type, None)

    def process_item(self, item, spider=None, *args, **kwargs):
        db = self.get_db_session(item, spider)
        if not db:
            raise DropItem("db session is none, item -> {}".format(item))
        try:
            model_cls = self.get_model_cls(item)
            model_kwargs = self.get_model_kwargs(item, spider) or {}
            if model_cls and issubclass(model_cls, BaseModel):
                model = model_cls.save(item, **model_kwargs)
                db.add(model)
                db.commit()
        except Exception as e:
            db.rollback()
            error = traceback.format_exc()
            spider.log(error, level=logging.ERROR)
            raise DropItem("db commit error, item -> {}".format(item))
        return item

    def get_db_session(self, item=None, spider=None):
        if self._db_session:
            return self._db_session
        self._db_session = self.init_db_session(item=item, spider=spider)
        return self._db_session
